==> zego_zpns-2.3.0%2B1.tar.gz: ios/Classes/internal/ZPNsMethodManager.m <==
//
//  ZPNsMethodManager.m
//  zego_zpns
//
//  Created by 武耀琳 on 2023/3/6.
//

#import "ZPNsMethodManager.h"
#import <Flutter/Flutter.h>
#import <Foundation/Foundation.h>
#import "NSDictionary+safeInvoke.h"
#import "NSMutableDictionary+safeInvoke.h"
#import "ZPNsSettings.h"
#import "CallKitManager.h"
#import <ZPNs/ZPNs.h>
#import "UUIDManager.h"
@interface ZPNsMethodManager ()<ZPNsNotificationCenterDelegate>

@property bool debug;

@end

@implementation ZPNsMethodManager

+ (instancetype)sharedInstance {
    static ZPNsMethodManager *instance = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        instance = [[ZPNsMethodManager alloc] init];
    });
    return instance;
}


-(void)getPlatformVersion:(FlutterMethodCall *)call result:(FlutterResult)result {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
}

-(void)getVersion:(FlutterMethodCall *)call result:(FlutterResult)result {
    result([ZPNs getVersion]);
}

-(void)applyNotificationPermission:(FlutterMethodCall *)call result:(FlutterResult)result {
    if (@available(iOS 10.0, *)) {
        UNUserNotificationCenter *center = [UNUserNotificationCenter currentNotificationCenter];
        center.delegate = (id)[ZPNs shared];
        [center requestAuthorizationWithOptions:(UNAuthorizationOptionAlert | UNAuthorizationOptionBadge | UNAuthorizationOptionSound) completionHandler:^(BOOL granted, NSError * _Nullable error) {
            if (granted) {
                //点击允许
                [center getNotificationSettingsWithCompletionHandler:^(UNNotificationSettings * _Nonnull settings) {
                    
                }];
                
            } else {
                
            }
        }];
    }else if ([[UIDevice currentDevice].systemVersion floatValue] >8.0){
        //iOS8 - iOS10
        [[UIApplication sharedApplication] registerUserNotificationSettings:[UIUserNotificationSettings settingsForTypes:UIUserNotificationTypeAlert | UIUserNotificationTypeSound | UIUserNotificationTypeBadge categories:nil]];
    }else {
        // Fallback on earlier versions
        
    }
    result(nil);
}

-(void)enableDebug:(FlutterMethodCall *)call result:(FlutterResult)result {
    self.debug = [[call.arguments objectForKey:@"debug"] boolValue];
    result(nil);
}

-(void)getPushConfig:(FlutterMethodCall *)call result:(FlutterResult)result {
    result(nil);
}

-(void)setPushConfig:(FlutterMethodCall *)call result:(FlutterResult)result {
    result(nil);
}

-(void)registerPush:(FlutterMethodCall *)call result:(FlutterResult)result {
    NSDictionary *extendedData = [call.arguments safeObjectForKey:@"extendedData"];
    [[ZPNs shared] registerAPNs];
    bool enableIOSVoIP = [extendedData safeObjectForKey:@"enableIosVoIP"];
    if(enableIOSVoIP){
        [self voipRegistration];
    }
    result(nil);
}

-(void)addLocalNotification:(FlutterMethodCall *)call result:(FlutterResult)result {
    UNUserNotificationCenter *center = [UNUserNotificationCenter currentNotificationCenter];
    UNMutableNotificationContent *content = [[UNMutableNotificationContent alloc] init];
    NSDictionary *localMessageDic = [call.arguments safeObjectForKey:@"message"];
    content.title = [localMessageDic safeObjectForKey:@"title"];
    content.body = [localMessageDic safeObjectForKey:@"content"];
    NSMutableDictionary *userInfo = [[NSMutableDictionary alloc] init];
    [userInfo safeSetObject:[localMessageDic safeObjectForKey:@"payload"] forKey:@"payload"];
    content.userInfo = userInfo;
    
    NSString *sound = [localMessageDic safeObjectForKey:@"iOSSound"];
    if(sound != nil && ![sound isEqual:@""]){
        content.sound = [UNNotificationSound soundNamed:sound];
    }
    
#if __IPHONE_OS_VERSION_MAX_ALLOWED >= 150000
    if (@available(iOS 15.0, *)) {
        content.interruptionLevel = UNNotificationInterruptionLevelActive;
    }
#endif
    UNNotificationRequest *request = [UNNotificationRequest requestWithIdentifier:@"" content:content trigger:nil];
    [center addNotificationRequest:request withCompletionHandler:^(NSError * _Nullable error) {
        
    }];
    result(nil);
}

-(void)createNotificationChannel:(FlutterMethodCall *)call result:(FlutterResult)result {
    result(nil);
}


#pragma mark - CallKit

-(void)reportIncomingCallWithTitle:(FlutterMethodCall *)call result:(FlutterResult)result {
    [[CallKitManager getInstance] reportIncomingCallWithTitle:[call.arguments safeObjectForKey:@"cxCallUpdate"] UUID:[call.arguments safeObjectForKey:@"uuidSeq"]];
}

-(void)setCallKitInitConfig:(FlutterMethodCall *)call result:(FlutterResult)result{
    NSDictionary *initConfigMap = [call.arguments safeObjectForKey:@"config"];
    [[CallKitManager getInstance] setInitConfig:initConfigMap];
    result(nil);
}

-(void)reportCallEnded:(FlutterMethodCall *)call result:(FlutterResult)result{
    NSNumber *endedReason = [call.arguments safeObjectForKey:@"endedReason"];
    NSString *uuidSeq = [call.arguments safeObjectForKey:@"uuidSeq"];
    [[CallKitManager getInstance] reportCallEndedWithUUID:uuidSeq reason:[endedReason intValue]];
}


-(void)reportCallUpdate:(FlutterMethodCall *)call result:(FlutterResult)result{
    [[CallKitManager getInstance] reportCallUpdateWithUUID:[call.arguments safeObjectForKey:@"cxCallUpdate"] UUID:[call.arguments safeObjectForKey:@"uuidSeq"]];
}

-(void)reportOutgoingCall:(FlutterMethodCall *)call result:(FlutterResult)result{
    [[CallKitManager getInstance] reportOutgoingCallWithUUID:[call.arguments safeObjectForKey:@"uuidSeq"]];
}


-(void)generateUUID:(FlutterMethodCall *)call result:(FlutterResult)result{
    [[UUIDManager getInstance] generateUUID:[call.arguments safeObjectForKey:@"seq"]];
}

-(void)callKitActionFail:(FlutterMethodCall *)call result:(FlutterResult)result{
    NSString *seq = [call.arguments safeObjectForKey:@"seq"];
    [[CallKitManager getInstance] ActionFail:seq];
}
-(void)callKitActionFulfill:(FlutterMethodCall *)call result:(FlutterResult)result{
    NSString *seq = [call.arguments safeObjectForKey:@"seq"];
    [[CallKitManager getInstance] ActionFullFill:seq];
}

-(void)didReceiveIncomingPushCompletion:(FlutterMethodCall *)call result:(FlutterResult)result{
    NSString *seq = [call.arguments safeObjectForKey:@"seq"];
    [[CallKitManager getInstance] didReceiveIncomingPushCompletion:seq];
}

-(void)didReceiveRemoteNotificationCompletion:(FlutterMethodCall *)call result:(FlutterResult)result{
    NSString *seq = [call.arguments safeObjectForKey:@"seq"];
    NSNumber *fetchResult= [call.arguments safeObjectForKey:@"result"];
    id completion = [ZPNsSettings.didReceiveRemoteNotificationCompletionSeqMap safeObjectForKey:seq];
    ((void (^)(UIBackgroundFetchResult result))completion)([fetchResult unsignedIntegerValue]);
}
#pragma mark - utils
-(void)voipRegistration{
    dispatch_queue_t mainQueue = dispatch_get_main_queue();
    PKPushRegistry *voipRegistry = [[PKPushRegistry alloc] initWithQueue:mainQueue];
    [voipRegistry setDelegate:[CallKitManager getInstance]];
    [CallKitManager isProduct:!self.debug];
    NSMutableSet *desiredPushTypes = [[NSMutableSet alloc] init];
    [desiredPushTypes addObject:PKPushTypeVoIP];
    voipRegistry.desiredPushTypes = desiredPushTypes;
}
@end

==> zego_zpns-2.3.2%2B1.tar.gz: ios/Classes/internal/ZPNsMethodManager.m <==
//
//  ZPNsMethodManager.m
//  zego_zpns
//
//  Created by 武耀琳 on 2023/3/6.
//

#import "ZPNsMethodManager.h"
#import <Flutter/Flutter.h>
#import <Foundation/Foundation.h>
#import "utils/NSDictionary+safeInvoke.h"
#import "utils/NSMutableDictionary+safeInvoke.h"
#import "ZPNsSettings.h"
#import "CallKitManager.h"
#import <ZPNs/ZPNs.h>
#import "UUIDManager.h"
@interface ZPNsMethodManager ()<ZPNsNotificationCenterDelegate>

@end

@implementation ZPNsMethodManager

+ (instancetype)sharedInstance {
    static ZPNsMethodManager *instance = nil;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        instance = [[ZPNsMethodManager alloc] init];
    });
    return instance;
}


-(void)getPlatformVersion:(FlutterMethodCall *)call result:(FlutterResult)result {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
}

-(void)getVersion:(FlutterMethodCall *)call result:(FlutterResult)result {
    result([ZPNs getVersion]);
}

-(void)applyNotificationPermission:(FlutterMethodCall *)call result:(FlutterResult)result {
    if (@available(iOS 10.0, *)) {
        UNUserNotificationCenter *center = [UNUserNotificationCenter currentNotificationCenter];
        center.delegate = (id)[ZPNs shared];
        [center requestAuthorizationWithOptions:(UNAuthorizationOptionAlert | UNAuthorizationOptionBadge | UNAuthorizationOptionSound) completionHandler:^(BOOL granted, NSError * _Nullable error) {
            if (granted) {
                //点击允许
                [center getNotificationSettingsWithCompletionHandler:^(UNNotificationSettings * _Nonnull settings) {
                    
                }];
                
            } else {
                
            }
        }];
    }else if ([[UIDevice currentDevice].systemVersion floatValue] >8.0){
        //iOS8 - iOS10
        [[UIApplication sharedApplication] registerUserNotificationSettings:[UIUserNotificationSettings settingsForTypes:UIUserNotificationTypeAlert | UIUserNotificationTypeSound | UIUserNotificationTypeBadge categories:nil]];
    }else {
        // Fallback on earlier versions
        
    }
    result(nil);
}

-(void)enableDebug:(FlutterMethodCall *)call result:(FlutterResult)result {
    self.debug = [[call.arguments objectForKey:@"debug"] boolValue];
    result(nil);
}

-(void)getPushConfig:(FlutterMethodCall *)call result:(FlutterResult)result {
    result(nil);
}

-(void)setPushConfig:(FlutterMethodCall *)call result:(FlutterResult)result {
    result(nil);
}

-(void)registerPush:(FlutterMethodCall *)call result:(FlutterResult)result {
    NSDictionary *extendedData = [call.arguments safeObjectForKey:@"extendedData"];
    [[ZPNs shared] registerAPNs];
    bool enableIOSVoIP = [extendedData safeObjectForKey:@"enableIosVoIP"];
    if(enableIOSVoIP){
        [self voipRegistration];
    }
    result(nil);
}

-(void)addLocalNotification:(FlutterMethodCall *)call result:(FlutterResult)result {
    UNUserNotificationCenter *center = [UNUserNotificationCenter currentNotificationCenter];
    UNMutableNotificationContent *content = [[UNMutableNotificationContent alloc] init];
    NSDictionary *localMessageDic = [call.arguments safeObjectForKey:@"message"];
    content.title = [localMessageDic safeObjectForKey:@"title"];
    content.body = [localMessageDic safeObjectForKey:@"content"];
    NSMutableDictionary *userInfo = [[NSMutableDictionary alloc] init];
    [userInfo safeSetObject:[localMessageDic safeObjectForKey:@"payload"] forKey:@"payload"];
    content.userInfo = userInfo;
    
    NSString *sound = [localMessageDic safeObjectForKey:@"iOSSound"];
    if(sound != nil && ![sound isEqual:@""]){
        content.sound = [UNNotificationSound soundNamed:sound];
    }
    
#if __IPHONE_OS_VERSION_MAX_ALLOWED >= 150000
    if (@available(iOS 15.0, *)) {
        content.interruptionLevel = UNNotificationInterruptionLevelActive;
    }
#endif
    UNNotificationRequest *request = [UNNotificationRequest requestWithIdentifier:@"" content:content trigger:nil];
    [center addNotificationRequest:request withCompletionHandler:^(NSError * _Nullable error) {
        
    }];
    result(nil);
}

-(void)createNotificationChannel:(FlutterMethodCall *)call result:(FlutterResult)result {
    result(nil);
}


#pragma mark - CallKit

-(void)reportIncomingCallWithTitle:(FlutterMethodCall *)call result:(FlutterResult)result {
    [[CallKitManager getInstance] reportIncomingCallWithTitle:[call.arguments safeObjectForKey:@"cxCallUpdate"] UUID:[call.arguments safeObjectForKey:@"uuidSeq"]];
}

-(void)setCallKitInitConfig:(FlutterMethodCall *)call result:(FlutterResult)result{
    NSDictionary *initConfigMap = [call.arguments safeObjectForKey:@"config"];
    [[CallKitManager getInstance] setInitConfig:initConfigMap];
    result(nil);
}

-(void)reportCallEnded:(FlutterMethodCall *)call result:(FlutterResult)result{
    NSNumber *endedReason = [call.arguments safeObjectForKey:@"endedReason"];
    NSString *uuidSeq = [call.arguments safeObjectForKey:@"uuidSeq"];
    [[CallKitManager getInstance] reportCallEndedWithUUID:uuidSeq reason:[endedReason intValue]];
}


-(void)reportCallUpdate:(FlutterMethodCall *)call result:(FlutterResult)result{
    [[CallKitManager getInstance] reportCallUpdateWithUUID:[call.arguments safeObjectForKey:@"cxCallUpdate"] UUID:[call.arguments safeObjectForKey:@"uuidSeq"]];
}

-(void)reportOutgoingCall:(FlutterMethodCall *)call result:(FlutterResult)result{
    [[CallKitManager getInstance] reportOutgoingCallWithUUID:[call.arguments safeObjectForKey:@"uuidSeq"]];
}


-(void)generateUUID:(FlutterMethodCall *)call result:(FlutterResult)result{
    [[UUIDManager getInstance] generateUUID:[call.arguments safeObjectForKey:@"seq"]];
}

-(void)callKitActionFail:(FlutterMethodCall *)call result:(FlutterResult)result{
    NSString *seq = [call.arguments safeObjectForKey:@"seq"];
    [[CallKitManager getInstance] ActionFail:seq];
}
-(void)callKitActionFulfill:(FlutterMethodCall *)call result:(FlutterResult)result{
    NSString *seq = [call.arguments safeObjectForKey:@"seq"];
    [[CallKitManager getInstance] ActionFullFill:seq];
}

-(void)didReceiveRemoteNotificationCompletion:(FlutterMethodCall *)call result:(FlutterResult)result{
    NSString *seq = [call.arguments safeObjectForKey:@"seq"];
    NSNumber *fetchResult= [call.arguments safeObjectForKey:@"result"];
    id completion = [ZPNsSettings.didReceiveRemoteNotificationCompletionSeqMap safeObjectForKey:seq];
    ((void (^)(UIBackgroundFetchResult result))completion)([fetchResult unsignedIntegerValue]);
}
#pragma mark - utils
-(void)voipRegistration{
    dispatch_queue_t mainQueue = dispatch_get_main_queue();
    PKPushRegistry *voipRegistry = [[PKPushRegistry alloc] initWithQueue:mainQueue];
    [voipRegistry setDelegate:[CallKitManager getInstance]];
    [CallKitManager isProduct:!self.debug];
    NSMutableSet *desiredPushTypes = [[NSMutableSet alloc] init];
    [desiredPushTypes addObject:PKPushTypeVoIP];
    voipRegistry.desiredPushTypes = desiredPushTypes;
}
@end
